"""blog URL Configuration.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.conf.urls.static import static
from django.contrib import admin
from django.urls import include, path
from django.views.generic import TemplateView
from two_factor.urls import urlpatterns as tf_urls  # type: ignore[import]

from blog import settings

urlpatterns = [
    path("", include(tf_urls)),
    path(
        "robots.txt",
        TemplateView.as_view(
            template_name="blog/robots.txt",
            content_type="text/plain",
        ),
    ),
    path("admin/", admin.site.urls),
    path("", include("articles.urls")),
    path("attachments/", include("attachments.urls")),
]

if settings.DEBUG:
    import debug_toolbar  # type: ignore[import]

    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
    urlpatterns += [path("__debug__/", include(debug_toolbar.urls))]
